==> pdf-model-arlington-1.25.15-sources.jar: org/verapdf/model/alayer/AMediaPlayers.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AMediaPlayers extends AObject {
	




	/**
	*/
	public Boolean getcontainsA();

	/**
	*/
	public Boolean getAHasTypeArray();

	/**
	*/
	public Boolean getcontainsMU();

	/**
	*/
	public Boolean getMUHasTypeArray();

	/**
	*/
	public Long getMUArraySize();

	/**
	*/
	public Boolean getcontainsNU();

	/**
	*/
	public Boolean getNUHasTypeArray();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();
}

==> pdf-model-arlington-1.27.13-sources.jar: org/verapdf/model/alayer/AMediaPlayers.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AMediaPlayers extends AObject {
	




	/**
	*/
	public Boolean getcontainsA();

	/**
	*/
	public String getAType();

	/**
	*/
	public Boolean getAHasTypeArray();

	/**
	*/
	public Boolean getcontainsMU();

	/**
	*/
	public String getMUType();

	/**
	*/
	public Boolean getMUHasTypeArray();

	/**
	*/
	public Long getMUArraySize();

	/**
	*/
	public Boolean getcontainsNU();

	/**
	*/
	public String getNUType();

	/**
	*/
	public Boolean getNUHasTypeArray();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();
}
